@@ -3,13 +3,13 @@
 from __future__ import annotations
 
 from textwrap import dedent
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 import markdown
 import pytest
 
-from mkdocs_autorefs.plugin import AutorefsPlugin
-from mkdocs_autorefs.references import AutorefsExtension, AutorefsHookInterface, fix_refs, relative_url
+from mkdocs_autorefs import AutorefsExtension, AutorefsHookInterface, AutorefsPlugin, fix_refs, relative_url
+from tests.helpers import create_page
 
 if TYPE_CHECKING:
     from collections.abc import Mapping
@@ -46,12 +46,15 @@ def test_relative_url(current_url: str, to_url: str, href_url: str) -> None:
 
 
 def run_references_test(
-    url_map: dict[str, str],
+    url_map: Mapping[str, str],
     source: str,
     output: str,
     unmapped: list[tuple[str, AutorefsHookInterface.Context | None]] | None = None,
     from_url: str = "page.html",
-    extensions: Mapping = {},
+    extensions: Mapping[str, Mapping[str, Any]] | None = None,
+    title_map: Mapping[str, str] | None = None,
+    *,
+    strip_tags: bool = True,
 ) -> None:
     """Help running tests about references.
 
@@ -62,13 +65,15 @@ def run_references_test(
         unmapped: The expected unmapped list.
         from_url: The source page URL.
     """
+    extensions = extensions or {}
     md = markdown.Markdown(extensions=[AutorefsExtension(), *extensions], extension_configs=extensions)
     content = md.convert(source)
+    title_map = title_map or {}
 
-    def url_mapper(identifier: str) -> str:
-        return relative_url(from_url, url_map[identifier])
+    def url_mapper(identifier: str) -> tuple[str, str | None]:
+        return relative_url(from_url, url_map[identifier]), title_map.get(identifier, None)
 
-    actual_output, actual_unmapped = fix_refs(content, url_mapper)
+    actual_output, actual_unmapped = fix_refs(content, url_mapper, strip_title_tags=strip_tags)
     assert actual_output == output
     assert actual_unmapped == (unmapped or [])
 
@@ -257,8 +262,8 @@ def test_custom_optional_reference() -> None:
     """Check that optional HTML-based references are expanded and never reported missing."""
     run_references_test(
         url_map={"ok": "ok.html#ok"},
-        source='<autoref optional identifier="bar">foo</autoref> <autoref identifier=ok optional>ok</autoref>',
-        output='<p>foo <a class="autorefs autorefs-internal" href="ok.html#ok">ok</a></p>',
+        source='<autoref optional identifier="foo">bar</autoref> <autoref optional identifier="ok">ok</autoref>',
+        output='<p><span title="foo">bar</span> <a class="autorefs autorefs-internal" href="ok.html#ok">ok</a></p>',
     )
 
 
@@ -273,15 +278,6 @@ def test_legacy_custom_optional_hover_reference() -> None:
         )
 
 
-def test_custom_optional_hover_reference() -> None:
-    """Check that optional-hover HTML-based references are expanded and never reported missing."""
-    run_references_test(
-        url_map={"ok": "ok.html#ok"},
-        source='<autoref optional hover identifier="bar">foo</autoref> <autoref optional identifier=ok hover>ok</autoref>',
-        output='<p><span title="bar">foo</span> <a class="autorefs autorefs-internal" title="ok" href="ok.html#ok">ok</a></p>',
-    )
-
-
 # YORE: Bump 2: Remove block.
 def test_legacy_external_references() -> None:
     """Check that external references are marked as such."""
@@ -306,7 +302,7 @@ def test_register_markdown_anchors() -> None:
     """Check that Markdown anchors are registered when enabled."""
     plugin = AutorefsPlugin()
     md = markdown.Markdown(extensions=["attr_list", "toc", AutorefsExtension(plugin)])
-    plugin.current_page = "page"
+    plugin.current_page = create_page("page")
     md.convert(
         dedent(
             """
@@ -367,7 +363,7 @@ def test_register_markdown_anchors_with_admonition() -> None:
     """Check that Markdown anchors are registered inside a nested admonition element."""
     plugin = AutorefsPlugin()
     md = markdown.Markdown(extensions=["attr_list", "toc", "admonition", AutorefsExtension(plugin)])
-    plugin.current_page = "page"
+    plugin.current_page = create_page("page")
     md.convert(
         dedent(
             """
@@ -405,8 +401,8 @@ def test_keep_data_attributes() -> None:
     """Keep HTML data attributes from autorefs spans."""
     run_references_test(
         url_map={"example": "https://e.com#a"},
-        source='<autoref optional identifier="example" class="hi ho" data-foo data-bar="0">e</autoref>',
-        output='<p><a class="autorefs autorefs-external hi ho" href="https://e.com#a" data-foo data-bar="0">e</a></p>',
+        source='<autoref optional identifier="example" class="hi ho" data-foo data-bar="0">example</autoref>',
+        output='<p><a class="autorefs autorefs-external hi ho" href="https://e.com#a" data-foo data-bar="0">example</a></p>',
     )
 
 
@@ -434,7 +430,7 @@ def test_mark_identifiers_as_exact(markdown_ref: str, exact_expected: bool) -> N
     """Mark code and explicit identifiers as exact (no `slug` attribute in autoref elements)."""
     plugin = AutorefsPlugin()
     md = markdown.Markdown(extensions=["attr_list", "toc", AutorefsExtension(plugin)])
-    plugin.current_page = "page"
+    plugin.current_page = create_page("page")
     output = md.convert(markdown_ref)
     if exact_expected:
         assert "slug=" not in output
@@ -486,3 +482,22 @@ def test_no_fallback_for_provided_identifiers() -> None:
         output="<p>[Hello][Hello world]</p>",
         unmapped=[("Hello world", None)],
     )
+
+
+def test_title_use_identifier() -> None:
+    """Check that the identifier is used for the title."""
+    run_references_test(
+        url_map={"fully.qualified.name": "ok.html#fully.qualified.name"},
+        source='<autoref optional identifier="fully.qualified.name">name</autoref>',
+        output='<p><a class="autorefs autorefs-internal" title="fully.qualified.name" href="ok.html#fully.qualified.name">name</a></p>',
+    )
+
+
+def test_title_append_identifier() -> None:
+    """Check that the identifier is appended to the title."""
+    run_references_test(
+        url_map={"fully.qualified.name": "ok.html#fully.qualified.name"},
+        title_map={"fully.qualified.name": "Qualified Name"},
+        source='<autoref optional identifier="fully.qualified.name">name</autoref>',
+        output='<p><a class="autorefs autorefs-internal" title="Qualified Name (fully.qualified.name)" href="ok.html#fully.qualified.name">name</a></p>',
+    )
